pub struct MppiGateRaceReport2D {
pub passed_gates: usize,
pub active_gate_index: usize,
pub cost: f64,
pub final_gate_distance: f64,
pub final_lateral_error: f64,
}Expand description
Summary for scoring a trajectory against a gate race.
Fields
passed_gates: usizeactive_gate_index: usizecost: f64final_gate_distance: f64final_lateral_error: f64Trait Implementations
Sourceimpl Clone for MppiGateRaceReport2D
impl Clone for MppiGateRaceReport2D
Sourcefn clone(&self) -> MppiGateRaceReport2D
fn clone(&self) -> MppiGateRaceReport2D
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MppiGateRaceReport2D
impl Debug for MppiGateRaceReport2D
Sourceimpl PartialEq for MppiGateRaceReport2D
impl PartialEq for MppiGateRaceReport2D
Sourcefn eq(&self, other: &MppiGateRaceReport2D) -> bool
fn eq(&self, other: &MppiGateRaceReport2D) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MppiGateRaceReport2D
impl StructuralPartialEq for MppiGateRaceReport2D