MppiRacingGate2D

Struct MppiRacingGate2D 

pub struct MppiRacingGate2D {
    pub center_x: f64,
    pub center_y: f64,
    pub normal_x: f64,
    pub normal_y: f64,
    pub half_width: f64,
}
2-D racing gate for reference-free MPPI progress objectives.

The normal points in the race direction. A gate is crossed when a rollout segment moves from the negative to the positive side of the gate plane and intersects the gate within half_width.

Fields

center_x: f64center_y: f64normal_x: f64normal_y: f64half_width: f64

Implementations

Source

impl MppiRacingGate2D

pub fn new( center_x: f64, center_y: f64, normal_x: f64, normal_y: f64, half_width: f64, ) -> RoboticsResult<Self>

pub fn center(&self) -> (f64, f64)

pub fn signed_distance(&self, x: f64, y: f64) -> f64

pub fn lateral_distance(&self, x: f64, y: f64) -> f64

pub fn squared_distance(&self, x: f64, y: f64) -> f64

pub fn crosses( &self, from: MppiState2D, to: MppiState2D, tolerance: f64, ) -> bool

pub fn state_is_past_gate(&self, state: MppiState2D, tolerance: f64) -> bool