pub struct MppiTerminalValueUpdateReport2D {
pub updates: usize,
pub mean_abs_delta: f64,
pub max_abs_delta: f64,
pub start_target: f64,
pub terminal_target: f64,
}Expand description
Summary returned after updating a terminal value grid from one rollout.
Fields
updates: usizemean_abs_delta: f64max_abs_delta: f64start_target: f64terminal_target: f64Trait Implementations
Sourceimpl Clone for MppiTerminalValueUpdateReport2D
impl Clone for MppiTerminalValueUpdateReport2D
Sourcefn clone(&self) -> MppiTerminalValueUpdateReport2D
fn clone(&self) -> MppiTerminalValueUpdateReport2D
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for MppiTerminalValueUpdateReport2D
impl PartialEq for MppiTerminalValueUpdateReport2D
Sourcefn eq(&self, other: &MppiTerminalValueUpdateReport2D) -> bool
fn eq(&self, other: &MppiTerminalValueUpdateReport2D) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MppiTerminalValueUpdateReport2D
impl StructuralPartialEq for MppiTerminalValueUpdateReport2D