pub struct MppiPersonFollowingCandidate2D {}Expand description
Candidate following point evaluated around the predicted target person.
Fields
x: f64y: f64offset_x: f64offset_y: f64distance_to_target: f64bearing: f64total_cost: f64visibility_cost: f64proximity_cost: f64distance_cost: f64travel_cost: f64stickiness_cost: f64feasible: boolTrait Implementations
Sourceimpl Clone for MppiPersonFollowingCandidate2D
impl Clone for MppiPersonFollowingCandidate2D
Sourcefn clone(&self) -> MppiPersonFollowingCandidate2D
fn clone(&self) -> MppiPersonFollowingCandidate2D
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for MppiPersonFollowingCandidate2D
impl PartialEq for MppiPersonFollowingCandidate2D
Sourcefn eq(&self, other: &MppiPersonFollowingCandidate2D) -> bool
fn eq(&self, other: &MppiPersonFollowingCandidate2D) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MppiPersonFollowingCandidate2D
impl StructuralPartialEq for MppiPersonFollowingCandidate2D