pub struct MultiPushReport {
pub objects: Vec<PushReport>,
pub final_poses: Vec<[f64; 3]>,
pub max_position_error: f64,
pub max_heading_error: f64,
}Expand description
Metrics for a multi-object push.
Fields
objects: Vec<PushReport>Per-object push reports, in the order the objects were pushed.
final_poses: Vec<[f64; 3]>Final pose of every object (same indexing as the inputs).
max_position_error: f64max_heading_error: f64Trait Implementations
Sourceimpl Clone for MultiPushReport
impl Clone for MultiPushReport
Sourcefn clone(&self) -> MultiPushReport
fn clone(&self) -> MultiPushReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiPushReport
impl Debug for MultiPushReport
Sourceimpl PartialEq for MultiPushReport
impl PartialEq for MultiPushReport
Sourcefn eq(&self, other: &MultiPushReport) -> bool
fn eq(&self, other: &MultiPushReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MultiPushReport