pub struct PusherMppiConfig {Show 14 fields
pub horizon: usize,
pub samples: usize,
pub dt: f64,
pub contact_sigma: f64,
pub tangent_sigma: f64,
pub push_sigma: f64,
pub push_speed: f64,
pub max_push_speed: f64,
pub position_weight: f64,
pub heading_weight: f64,
pub obstacle_weight: f64,
pub obstacle_radius: f64,
pub lambda: f64,
pub seed: u64,
}Expand description
Configuration for the sampling-based pushing controller.
Fields
horizon: usizesamples: usizedt: f64contact_sigma: f64Std-dev of the contact-offset perturbation [m].
tangent_sigma: f64Std-dev of the tangential-slip perturbation [m/s].
push_sigma: f64Std-dev of the normal-push perturbation [m/s].
push_speed: f64Initial (nominal) normal push speed [m/s].
max_push_speed: f64Maximum normal push speed [m/s] (the controller may slow toward 0).
position_weight: f64heading_weight: f64obstacle_weight: f64Penalty weight for the slider center entering an obstacle keep-out disc.
obstacle_radius: f64Keep-out radius around each obstacle center [m] (0 disables it).
lambda: f64seed: u64Trait Implementations
Sourceimpl Clone for PusherMppiConfig
impl Clone for PusherMppiConfig
Sourcefn clone(&self) -> PusherMppiConfig
fn clone(&self) -> PusherMppiConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PusherMppiConfig
impl Debug for PusherMppiConfig
Sourceimpl Default for PusherMppiConfig
impl Default for PusherMppiConfig
Sourceimpl PartialEq for PusherMppiConfig
impl PartialEq for PusherMppiConfig
Sourcefn eq(&self, other: &PusherMppiConfig) -> bool
fn eq(&self, other: &PusherMppiConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PusherMppiConfig