MotorQuadParams

Struct MotorQuadParams 

pub struct MotorQuadParams {
    pub gravity: f64,
    pub drag: f64,
    pub max_rotor_thrust: f64,
    pub torque_gain: f64,
    pub yaw_gain: f64,
    pub rate_damping: f64,
    pub max_speed: f64,
}
Motor-level quadrotor parameters and actuation limits.

Fields

gravity: f64

Downward gravitational acceleration [m/s^2].

drag: f64

Linear aerodynamic drag coefficient [1/s].

max_rotor_thrust: f64

Maximum thrust per rotor [m/s^2] (mass-normalized).

torque_gain: f64

Roll/pitch angular-acceleration gain per unit rotor-thrust difference.

yaw_gain: f64

Yaw angular-acceleration gain per unit rotor-thrust difference.

rate_damping: f64

Aerodynamic body-rate damping [1/s].

max_speed: f64

Maximum speed [m/s].

Implementations

Source

impl MotorQuadParams

pub fn new( gravity: f64, drag: f64, max_rotor_thrust: f64, torque_gain: f64, yaw_gain: f64, rate_damping: f64, max_speed: f64, ) -> RoboticsResult<Self>

pub fn saturate(self, command: MotorCommand) -> MotorCommand

Clamp each rotor thrust to [0, max_rotor_thrust].

pub fn is_saturated(self, command: MotorCommand) -> bool

Whether any rotor of the command is at (or above) its thrust limit.

pub fn step( self, state: MotorQuadState, command: MotorCommand, dt: f64, ) -> MotorQuadState

Advance the quadrotor one step under the rotor command.