pub struct MotorRacingLapReport {Show 15 fields
pub steps: usize,
pub gates_passed: usize,
pub laps_completed: usize,
pub lap_fraction: f64,
pub mean_speed: f64,
pub max_speed: f64,
pub path_length: f64,
pub gate_distance: f64,
pub min_aperture_margin: f64,
pub mean_tilt: f64,
pub max_tilt: f64,
pub max_body_rate: f64,
pub saturation_fraction: f64,
pub first_lap_time: Option<f64>,
pub path: Vec<[f64; 3]>,
}Expand description
Lap-progress, attitude, and motor-saturation metrics.
Fields
steps: usizegates_passed: usizelaps_completed: usizelap_fraction: f64mean_speed: f64max_speed: f64path_length: f64gate_distance: f64min_aperture_margin: f64mean_tilt: f64max_tilt: f64max_body_rate: f64saturation_fraction: f64Fraction of executed steps whose rotor command hit a thrust limit.
first_lap_time: Option<f64>path: Vec<[f64; 3]>Trait Implementations
Sourceimpl Clone for MotorRacingLapReport
impl Clone for MotorRacingLapReport
Sourcefn clone(&self) -> MotorRacingLapReport
fn clone(&self) -> MotorRacingLapReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MotorRacingLapReport
impl Debug for MotorRacingLapReport
Sourceimpl PartialEq for MotorRacingLapReport
impl PartialEq for MotorRacingLapReport
Sourcefn eq(&self, other: &MotorRacingLapReport) -> bool
fn eq(&self, other: &MotorRacingLapReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MotorRacingLapReport